      /DEFINE HSpec
      /INCLUDE ROUTINES/QRPGLESRC,HSPEC
     H Bnddir('ROUTINES/SRVPGM':'QC2LE':'ROUTINES/QJOURNAL')
      /UNDEFINE HSpec


      ***************************************************************************
      * Program: Purge journal recievers that have been detached for longer     *
      * than the number of days as passed in.  They must have also been saved.  *
      *                                                                         *
      * Modification log:                                                       *
      * 01/23/06 by R.Berendt, CCP    Group Dekko Services, LLC                 *
      *          Created.                                                       *
      *                                                                         *
      * Compilation instructions:                                               *
      *   (no special instructions this time.)                                  *
      *                                                                         *
      ***************************************************************************


      /DEFINE DSpec
      /INCLUDE ROUTINES/QPROTOSRC,PRGJRNRCV
      * Store the following prototype into the above member, and remove the
      * prototype from this member.
      /INCLUDE ROUTINES/QRPGLESRC,PSDS
      /INCLUDE ROUTINES/QAPISRC,ERRC0100
      /INCLUDE ROUTINES/QAPISRC,QUSDLTUS
      /INCLUDE ROUTINES/QAPISRC,QCMDEXC
      /If not defined(RRCV0100)
      /Include ROUTINES/QAPISRC,RRCV0100
      /EndIf

     D PRGJRNRCV       PI                                                       *ENTRY PLIST
     D  JrnRcv                             const like(Input)
     D  DetachDays                   10i 0 const

     D Input           ds                  qualified
     D  Journal                      10a
     D  Library                      10a

     D ProcessReceiver...
     D                 PR
     D  P1                                 likeDs(Input)

     D ProcessList     PR
     D  P1                                 likeDs(Input)

     D ProcessError    PR

      /UNDEFINE DSpec


      /free
       *inlr=*on;
       Input=JrnRcv;
       // If a generic journal receiver name is passed in, then process that group.
       // Otherwise, jump right into processing an individual entry.
       Select;
       When %scan('*':Input.Journal)=0;  // Not a generic receiver name
         ProcessReceiver(Input);
       Other;  // generic receiver
         ProcessList(Input);
       EndSl;
       return;
      /end-free

      /eject
     P ProcessReceiver...
     P                 B
     D ProcessReceiver...
     D                 PI
     D  Parm                               LikeDs(Input)

     D CheckPSDS       s                   like(mypsds)
     D DetachDate      s               d

      /free
       // If the receiver's detach date is not blank, and if the number of days
       // between the detach date is greater than the requested span, and if the
       // receiver's save date is not blank, then delete this receiver.
       // First, let's retrieve the attributes of this journal.
       reset errc0100;
       RtvJrnRcvI(RRCV0100: %len(RRCV0100) : Parm : 'RRCV0100':errc0100);
       Select;
       // Many of the exceptions have no processing yet.  Kinda there for
       // documentation of possible future additional processing you may want
       // to do.  Also will tell it to not process it as if it was not an
       // exception (like further down the When's).
       When ExceptionId='CPF9810';
         // Receiver library not found
         ProcessError();
       When ExceptionId='CPF9801';
         // Receiver not found
         ProcessError();
       When ExceptionId='CPF9820';
         // Not authorized to library
         ProcessError();
       When ExceptionId='CPF9802';
         // Not authorized to receiver
         ProcessError();
       When ExceptionId='CPF9803';
         // Cannot allocate receiver
         ProcessError();
       When ExceptionId<>*blanks;
         // Error retrieving journal receiver attributes
         ProcessError();
       When (RRCV0100.Status<>'3') and
            (RRCV0100.Status<>'4');  // not saved after detached
         // Skip it.  We only want to purge journal receivers that are detached
         // and have been saved.
       When %diff(%date():%date(%subst(RRCV0100.DetachDT:1:7):*CYMD0):*days)
            < DetachDays;
         // Hasn't been detached long enough.  Skip it.
       Other;
         // By now we have determined that we can purge this journal receiver
         cmd='DLTJRNRCV JRNRCV(' + %trim(parm.library) + '/' +
             %trim(parm.journal) + ') DLTOPT(*NONE)';
         callp(e) qcmdexc(cmd:%len(cmd));
         Select;
         When mypsds.excp_msg<>*blanks;
           // Alert the troops!
           eSubject='Unable to delete journal receiver ' + %trim(parm.library) +
                    '/' + %trim(parm.journal);
           eMessage=eSubject;
           CheckPSDS=fndsigmsg(mypsds);
           excphdlr01(eSubject: eMessage: CheckPSDS);
         EndSl;
       EndSl;
       return;
      /end-free
     P ProcessReceiver...
     P                 E

      /eject
     P ProcessList     B
     D ProcessList     PI
     D  Parm                               LikeDs(Input)
     D UserSpace       C                   'OBJLIST   QTEMP      '
      /free
       // List journal receivers that meet the criteria specified in Parm to a
       // user space.

       // Delete user space if it already exists
       reset errc0100;
       qusdltus(UserSpace:errc0100);
       if ExceptionId<>*blanks and ExceptionID<>'CPF2105'; // CPF2105 = not found
        // ERROR:  What should we do?
        Select;
        When ExceptionId='xxx1111'; // ddfaf
        When ExceptionId='yyy2222'; //  asdsdf
        Other; // Default for other errors
        EndSl;
       EndIf;

       // Create the user space
       reset errc0100;
       quscrtus(UserSpace:'QUSLOBJ':1000000:X'00':'*EXCLUDE':
                'List journal receivers':'*NO':errc0100);
       if ExceptionId<>*blanks;
        // ERROR:  What should we do?
        Select;
        When ExceptionId='xxx1111'; // ddfaf
        When ExceptionId='yyy2222'; //  asdsdf
        Other; // Default for other errors
        EndSl;
       EndIf;

       // List journal receivers to the user space
       reset errc0100;
       quslobj(UserSpace:'OBJL0100':Parm:'*JRNRCV':errc0100);
       if ExceptionId<>*blanks;
        // ERROR:  What should we do?
        Select;
        When ExceptionId='xxx1111'; // ddfaf
        When ExceptionId='yyy2222'; //  asdsdf
        Other; // Default for other errors
        EndSl;
       EndIf;

       // Retrieve pointer to the user space
       reset errc0100;
       qusptrus(UserSpace:pGH0100:errc0100);
       if ExceptionId<>*blanks;
        // ERROR:  What should we do?
        Select;
        When ExceptionId='xxx1111'; // ddfaf
        When ExceptionId='yyy2222'; //  asdsdf
        Other; // Default for other errors
        EndSl;
       EndIf;

       // Ok, now we have the list of receivers.  And we have positioned ourselves.
       // Now we be jammin'
       pGH0100List = pGH0100 + GHListOff;
       For ListEntry = 1 to GHListNbr;
        pOBJL = pGH0100List + (ListEntry - 1) * GHListMbrSz;
        ProcessReceiver(OLNamLib);
       EndFor;
       return;
      /end-free
     P ProcessList     E

      /eject
     P ProcessError    B
     D ProcessError    PI
      /free
       // This choice location for rent.
       return;
      /end-free
     P ProcessError    E  